@@ -59,7 +59,7 @@ use namespace::autoclean;
 use version 0.77;
 
 # ABSTRACT: Read annotated source manifest
-our $VERSION = 'v0.3.5'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::FileFinder';
@@ -123,17 +123,54 @@ sub _build_manifest_file {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method BUILD
+#pod
+#pod This method creates bunch of file finders: C<Manifest::Write/AllFiles>, C<Manifest::Write/ExecFiles>, C<Manifest::Write/ExtraTestFiles>, C<Manifest::Write/InstallModules>, C<Manifest::Write/PerlExecFiles>, C<Manifest::Write/TestFiles>.
+#pod
+#pod =cut
+
+sub BUILD {
+    my ( $self ) = @_;
+    require Dist::Zilla::Plugin::FinderCode;
+    my $parent = $self;
+    my $zilla  = $self->zilla;
+    my @finders = qw{ AllFiles ExecFiles ExtraTestFiles InstallModules PerlExecFiles TestFiles };
+    for my $name ( @finders ) {
+        my $finder = Dist::Zilla::Plugin::FinderCode->new( {
+            plugin_name => $self->plugin_name . '/' . $name,
+            zilla       => $zilla,
+            style       => 'list',
+            code        => sub {
+                my ( $self ) = @_;
+                my $plugin = $self->zilla->plugin_named( ':' . $name );
+                if ( not defined( $plugin ) ) {
+                    $parent->abort( [ "Can't find plugin %s", ':' . $name ] );
+                };
+                my @files = grep(
+                    { ( $parent->_file_hash->{ $_->name } || 0 ) == $_ }
+                    @{ $plugin->find_files() }
+                );
+                return \@files;
+            },
+        } );
+        push( @{ $zilla->plugins }, $finder );
+    };
+    return;
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method gather_files
 #pod
 #pod This method fulfills L<Dist::Zilla::Role::FileGatherer> role requirement. It adds files listed in
-#pod manifest to distribution (and to C<_files>). Files marked to exclude from distribution and
+#pod manifest to distribution (and to C<_file_list>). Files marked to exclude from distribution and
 #pod directories are not added.
 #pod
 #pod =cut
 
 sub gather_files {
     my ( $self ) = @_;
-    for my $file ( @{ $self->_files } ) {
+    for my $file ( @{ $self->_file_list } ) {
         $self->add_file( $file );
     };
     return;
@@ -144,7 +181,7 @@ sub gather_files {
 #pod =method find_files
 #pod
 #pod This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It simply returns a copy of
-#pod C<_files> attribute.
+#pod C<_file_list> attribute.
 #pod
 #pod This method can be called by other plugins to iterate through files added by C<Manifest::Read>,
 #pod see L</"SYNOPSIS">.
@@ -157,12 +194,12 @@ sub gather_files {
 
 sub find_files {
     my ( $self ) = @_;
-    return [ @{ $self->_files } ];
+    return [ @{ $self->_file_list } ];
 };
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =attr _files
+#pod =attr _file_list
 #pod
 #pod Array of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
 #pod marked for inclusion to the distribution.
@@ -171,15 +208,15 @@ sub find_files {
 #pod
 #pod =cut
 
-has _files => (
+has _file_list => (
     isa         => 'ArrayRef[Object]',
     is          => 'ro',
     lazy        => 1,
-    builder     => '_build_files',
+    builder     => '_build_file_list',
     init_arg    => undef,
 );
 
-sub _build_files {
+sub _build_file_list {
     my ( $self ) = @_;
     my $files = [];
     my @errors;
@@ -213,6 +250,31 @@ sub _build_files {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =attr _file_hash
+#pod
+#pod Hash of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
+#pod marked for inclusion to the distribution. Hash keys are file names, hash values are references to
+#pod file objects. Built from C<_file_list>.
+#pod
+#pod C<HasfRef>, read-only, lazy, initialized with builder.
+#pod
+#pod =cut
+
+has _file_hash => (
+    isa         => 'HashRef[Object]',
+    is          => 'ro',
+    lazy        => 1,
+    builder     => '_build_file_hash',
+    init_arg    => undef,
+);
+
+sub _build_file_hash {
+    my ( $self ) = @_;
+    return { map( { $_->name => $_ } @{ $self->_file_list } ) };
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =attr _lines
 #pod
 #pod Array of chomped manifest lines, including comments and empty lines.
@@ -399,7 +461,7 @@ Dist::Zilla::Plugin::Manifest::Read - Read annotated source manifest
 
 =head1 VERSION
 
-Version v0.3.5, released on 2015-10-29 22:42 UTC.
+Version v0.4.0, released on 2015-11-01 17:30 UTC.
 
 =head1 WHAT?
 
@@ -449,13 +511,21 @@ Manifest file as a C<Dist::Zilla> file object (C<Dist::Zilla::File::OnDisk>).
 
 C<Object>, read-only.
 
-=head2 _files
+=head2 _file_list
 
 Array of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
 marked for inclusion to the distribution.
 
 C<ArrayRef>, read-only, lazy, initialized with builder.
 
+=head2 _file_hash
+
+Hash of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
+marked for inclusion to the distribution. Hash keys are file names, hash values are references to
+file objects. Built from C<_file_list>.
+
+C<HasfRef>, read-only, lazy, initialized with builder.
+
 =head2 _lines
 
 Array of chomped manifest lines, including comments and empty lines.
@@ -464,16 +534,20 @@ C<ArrayRef[Str]>, read-only, lazy, initialized with builder.
 
 =head1 OBJECT METHODS
 
+=head2 BUILD
+
+This method creates bunch of file finders: C<Manifest::Write/AllFiles>, C<Manifest::Write/ExecFiles>, C<Manifest::Write/ExtraTestFiles>, C<Manifest::Write/InstallModules>, C<Manifest::Write/PerlExecFiles>, C<Manifest::Write/TestFiles>.
+
 =head2 gather_files
 
 This method fulfills L<Dist::Zilla::Role::FileGatherer> role requirement. It adds files listed in
-manifest to distribution (and to C<_files>). Files marked to exclude from distribution and
+manifest to distribution (and to C<_file_list>). Files marked to exclude from distribution and
 directories are not added.
 
 =head2 find_files
 
 This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It simply returns a copy of
-C<_files> attribute.
+C<_file_list> attribute.
 
 This method can be called by other plugins to iterate through files added by C<Manifest::Read>,
 see L</"SYNOPSIS">.
